﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace Test1
{
    public partial class Form1 : Form
    {
        public Form1()
        {
           InitializeComponent();

           // Our PictureBox must be told to accept Drag&Drop first
           // This is actually not in the property window and
           // even Intellisense doesnt show it! Anyway, it is
           // there, and this is safe to use =)
           pictureBox1.AllowDrop = true;
        }

        private void Form1_Load(object sender, EventArgs e)
        {

        }

        // This hooks into the global "Pressed a Key" routine
        protected override bool ProcessCmdKey(ref Message msg, Keys keyData) {
            // Checks if "Escape" was pressed
            if (keyData == Keys.Escape) {
                // Quits the application
                this.Close();
                return true;
            }
            // Hands the pressed key to the "normal" routine
            return base.ProcessCmdKey(ref msg, keyData);
        }

        // Method for the "Test" button
        private void bTest_Click(object sender, EventArgs e)
        {
            Bitmap bm = new Bitmap(pictureBox1.Width, pictureBox1.Height);
            for (int x = 0; x < pictureBox1.Width; x++)
                for (int y = 0; y < pictureBox1.Height; y++)
                {
                    int r = (x & y) % 256;
                    int g = (x * y / 100) % 256;
                    int b = (x + y) % 256;
                    Color col = Color.FromArgb(r, g, b);
                    bm.SetPixel(x, y, col);
                }
            pictureBox1.Image = bm;
        }

        // Method for the "Open" button
        private void bOpen_Click(object sender, EventArgs e)
        {
            //Create a new Open File Dialog
            OpenFileDialog ofd = new OpenFileDialog();
            //Show the Dialog
            if (DialogResult.OK == ofd.ShowDialog())
                //Attempt to load the selected file into the picture box
                pictureBox1.Load(ofd.FileName);
        }

        // Method for the "Save" button
        private void bSave_Click(object sender, EventArgs e)
        {
            // Create a new Save File Dialog
            SaveFileDialog sfd = new SaveFileDialog();
            // Show the Dialog
            if (DialogResult.OK == sfd.ShowDialog())
                //Attempt to save the content of the picture box
                pictureBox1.Image.Save(sfd.FileName);
        }

        // This is called when Drag and Drop is finished
        private void pictureBox1_DragDrop(object sender, DragEventArgs e)
        {
            // From the dropped object, extract a files list (it's always a list)
            String[] myFiles= (String[])e.Data.GetData(DataFormats.FileDrop, false);
            
            // From the first of that list, check extension...
            string ext = System.IO.Path.GetExtension(myFiles[0]).ToLower();
            // ... to be either of these, since we want to load an actual image
            if ((ext == ".jpg") || (ext == ".png") || (ext == ".bmp") || (ext == ".gif"))
            {
                // Attempt to load the image file into the picture box
                pictureBox1.Load(myFiles[0]);
            }
        }

        // This is called when something is dragged into the picture box
        private void pictureBox1_DragEnter(object sender, DragEventArgs e)
        {
            // Check if the dragged this is file(s)
            if (e.Data.GetDataPresent(DataFormats.FileDrop))
                // And give our "okay" for a copy
                e.Effect = DragDropEffects.Copy;
        }
    }
}
